##
#
# PLR (Packet Loss Rate) testing application for ESBs
#
# Copyright 2005-2007, Freie Universitaet Berlin. All rights reserved.
# Please refer to the COPYING file for detailed licensing information.
#
# Contributors: Georg Wittenburg
#
##

source scatterweb_esb.tcl

# Number of mobile nodes
set val(nn)	2

# Size of topography (m)
set val(x)	100
set val(y)	100

# Simulation duration (s)
set simulation_duration 1000000.0

source ns-2_simulation_header.tcl

# Create, initialize and connect nodes and agents
for {set i 0} {$i < $val(nn)} {incr i} {
	# Create mobile node
	set node_($i) [$ns_ node]
	# Disable random motion
	$node_($i) random-motion 0
	# Register node
	$god_ new_node $node_($i)
	$ns_ initial_node_pos $node_($i) 10

	# Create ScatterWeb ESB sensor node with PLRTest UserApp
	set agent_($i) [new Agent/MessagePassing/ScatterWeb/PLRTestESB]
	# Adjust packet size for ScatterWeb
	$agent_($i) set packetSize_ 1024
	# Set agent not to provide call traces
	$agent_($i) set strace_ false
	# Start mobile nodes
	$ns_ at 0 "$node_($i) start";
	# Load the EEPROM image into the agent
	$ns_ at 0.01 "$agent_($i) loadEEPROM eeprom.bin";
	# Set the ID of the ScatterWeb node
	$ns_ at 0.02 "$agent_($i) setNodeID [$node_($i) id]";
	# Initialize ScatterWeb firmware as soon as the simulation starts
	$ns_ at [$rng_ uniform 0.03 0.04] "$agent_($i) initFirmware";
	# Stop the agent when the simulation ends
	$ns_ at $simulation_duration "$agent_($i) stop";
	# Attach the ScatterWeb agent to the mobile node
	$node_($i) attach $agent_($i)
}

# Set position of first node
$node_(0) set X_ 0
$node_(0) set Y_ 0
$node_(0) set Z_ 0

# Set position of second node
$node_(1) set X_ 90
$node_(1) set Y_ 0
$node_(1) set Z_ 0

# Push the buttons to start transmissions and gather received packet numbers
for {set step 1} {$step <= 11} {incr step} {
	$ns_ at [expr $step * 10000] "$agent_(0) pushButton";
	$ns_ at [expr [expr $step * 10000] + 10000] "$agent_(1) pushButton";
}

source ns-2_simulation_footer.tcl
