##
#
# FACTS for ESBs
#
# Copyright 2005-2007, Freie Universitaet Berlin. All rights reserved.
# Please refer to the COPYING file for detailed licensing information.
#
# Contributors: Georg Wittenburg
#
##

source scatterweb_msb.tcl

# Number of mobile nodes
set val(nn)	10

# Size of topography (m)
set val(x)	500
set val(y)	500

# Simulation duration (s)
set simulation_duration 1.0

source ns-2_simulation_header.tcl

# Create, initialize and connect nodes and agents
for {set i 0} {$i < $val(nn)} {incr i} {
	# Create mobile node
	set node_($i) [$ns_ node]
	# Set initial position
	$node_($i) set X_ [$rng_ uniform 0 $val(x)]
	$node_($i) set Y_ [$rng_ uniform 0 $val(y)]
	$node_($i) set Z_ 0
	# Disable random motion
	$node_($i) random-motion 0
	# Register node.
	$god_ new_node $node_($i)
	$ns_ initial_node_pos $node_($i) 10

	# Create ScatterWeb MSB sensor node with FACTS UserApp
	set agent_($i) [new Agent/MessagePassing/ScatterWeb/FACTS_MSB]
	# Adjust packet size for ScatterWeb
	$agent_($i) set packetSize_ 1024
	# Set agent not to provide call traces
	$agent_($i) set strace_ false
	# Start mobile nodes
	$ns_ at 0 "$node_($i) start";
	# Load the EEPROM image into the agent
	$ns_ at 0.01 "$agent_($i) loadEEPROM eeprom_with_ruleset.bin";
	# Set the ID of the ScatterWeb node
	$ns_ at 0.02 "$agent_($i) setNodeID [$node_($i) id]";
	# Initialize ScatterWeb firmware as soon as the simulation starts
	$ns_ at [$rng_ uniform 0.03 0.04] "$agent_($i) initFirmware";
	# Stop the agent when the simulation ends
	$ns_ at $simulation_duration "$agent_($i) stop";
	# Attach the ScatterWeb agent to the mobile node
	$node_($i) attach $agent_($i) $MESSAGE_PORT
}

# Push the button
$ns_ at 0.25 "$agent_(0) pushButton";
$ns_ at 0.5 "$agent_(0) pushButton";
$ns_ at 0.75 "$agent_(0) pushButton";

source ns-2_simulation_footer.tcl
